Module dex

Module dex 

Generated Dex protocol.

Modules

flow_history_event
Nested message and enum types in FlowHistoryEvent.
flow_service_client
Generated client implementations.
flow_service_server
Generated server implementations.
flow_started_or_continued_history_event
Nested message and enum types in FlowStartedOrContinuedHistoryEvent.
internal_async_step_input_snapshot
Nested message and enum types in InternalAsyncStepInputSnapshot.
internal_flow_error
Nested message and enum types in InternalFlowError.
internal_service_client
Generated client implementations.
internal_service_server
Generated server implementations.
invoke_execute_method_output
Nested message and enum types in InvokeExecuteMethodOutput.
invoke_wait_for_method_output
Nested message and enum types in InvokeWaitForMethodOutput.
value
Nested message and enum types in Value.
wait_for_attribute_condition
Nested message and enum types in WaitForAttributeCondition.
worker_service_client
Generated client implementations.
worker_service_server
Generated server implementations.

Structs

ActiveStepExecutionState
AttributeStoreNames
AttributeSyncConfig
AttributeSyncItem
AttributeWrite
BlobStoreCleanupWorkflowInput
BlobStoreCleanupWorkflowOutput
ChannelCondition
ChannelExternalDeleteEvent
ChannelExternalPublishEvent
ChannelInfo
ChannelMessage
ChannelMessageDeletion
ChannelResult
ChannelValues
CleanupBlobStoreActivityInput
CleanupBlobStoreActivityOutput
CloseDecision
ConditionCombination
ConditionResults
Context
ContinueAsNewDump
ContinueAsNewDumpRequest
ContinueAsNewDumpResponse
ContinueAsNewInput
DebugDumpResponse
DeleteChannelMessageRequest
DumpFlowForContinueAsNewActivityInput
DumpFlowForContinueAsNewActivityOutput
EncodedObject
ExecuteRpcSignalRequest
FlowAlreadyStartedOptions
FlowClosedHistoryEvent
FlowConfig
FlowContinuedStart
FlowExecutionId
FlowHistoryEvent
FlowInitialStart
FlowResult
FlowRetryPolicy
FlowStartOptions
FlowStartedOrContinuedHistoryEvent
FlowTimeoutHandlerOptions
GetAttributesQueryRequest
GetAttributesQueryResponse
GetAttributesRequest
GetAttributesResponse
GetChannelMessagesRequest
GetChannelMessagesResponse
GetCurrentTimerInfosQueryResponse
GetFlowStateRequest
GetFlowStateResponse
GetFlowSummaryRequest
GetFlowSummaryResponse
GetHistoryEventsRequest
GetHistoryEventsResponse
GetScheduledGreedyTimerTimesQueryResponse
HealthInfo
IndexConfig
InternalActivityError
InternalAsyncStepInputSnapshot
InternalFlowError
InternalLocalActivityInput
InternalLocalStepActivityFailure
InternalWorkerError
InterpreterWorkflowInput
InterpreterWorkflowOutput
InvokeExecuteMethodActivityInput
InvokeExecuteMethodActivityOutput
InvokeExecuteMethodOutput
InvokeExecuteMethodRequest
InvokeExecuteMethodResponse
InvokeRpcRequest
InvokeRpcResponse
InvokeRpcUpdateResult
Sync-update InvokeRPC handler result when response and error are multiplexed.
InvokeWaitForMethodActivityInput
InvokeWaitForMethodActivityOutput
InvokeWaitForMethodOutput
InvokeWaitForMethodRequest
InvokeWaitForMethodResponse
InvokeWorkerRpcActivityInput
InvokeWorkerRpcActivityOutput
InvokeWorkerRpcRequest
InvokeWorkerRpcResponse
Kv
LoadBlobsRequest
LoadBlobsResponse
LocalActivityMetadata
PrepareRpcQueryRequest
PrepareRpcQueryResponse
PublishToChannelRequest
ReadStreamRequest
ReadStreamResponse
RecoveryErrorInfo
ReportSubFlowCompletionActivityInput
ReportSubFlowCompletionActivityOutput
ResetFlowRequest
ResetFlowResponse
RetryPolicy
RpcExecutionCompletedEvent
Successful RPC history projection. Updates include input/output; signals include them only when configured.
SearchFlowsRequest
SearchFlowsResponse
SearchFlowsResponseEntry
ServiceErrorResponse
SetAttributesRequest
SkipTimerRequest
SkipTimerSignalRequest
StaleSkipTimer
StartFlowRequest
StartFlowResponse
StartSubFlowActivityInput
StartSubFlowActivityOutput
StepCompletionOutput
StepDecision
StepExecuteCompletedEvent
StepExecuteCompletedOutput
StepExecuteFailedEvent
StepExecutionCompletedConditions
StepExecutionCounterInfo
StepExecutionNumbers
StepExecutionResumeInfo
StepMethodEventContext
StepMethodEventInput
StepMethodFailedOutput
StepMethodFailure
StepMethodHeartbeat
StepMethodOptions
StepMethodPendingEvent
StepMethodPendingEvent describes a regular Step activity unresolved at flow closure.
StepMovement
StepOptions
StepStreamWrite
StepWaitForCompletedEvent
StepWaitForCompletedOutput
StepWaitForFailedEvent
StopFlowRequest
StopFlowSignalRequest
StreamMessage
SubFlowCompletionSignalRequest
SubFlowCondition
SubFlowConditionState
SubFlowOptions
SyncAttributeBatchActivityInput
SyncAttributeIndexRequest
SyncAttributeIndexResponse
TimeTravelForkHistoryEvent
TimeTravelForkHistoryEvent identifies the preserved run whose history Time Travel forked.
TimerCondition
TimerInfo
TimerInfoList
TimerResult
TriggerContinueAsNewRequest
UpdateFlowConfigRequest
Value
WaitForAttributeCondition
WaitForAttributeEqual
WaitForAttributeRequest
WaitForFlowRequest
WaitForHistoryEventRequest
WaitForHistoryEventResponse
WaitForStepCompletionRequest
WaitForStepCompletionResponse
WaitingCondition
WaitingConditionState
WorkerErrorResponse
WorkerTarget
WriteStreamRequest

Enums

ActiveStepPhase
ActiveStepSearchMode
CloseDecisionType
ConditionStatus
ErrorSubStatus
ExecuteMethodFailurePolicy
FlowErrorType
FlowResetStepMethod
FlowResetType
FlowStatus
FlowTimeoutPolicy
IdReusePolicy
IndexType
InternalTimerStatus
PendingStepMethodPhase
PendingStepMethodPhase reports the latest persisted backend lifecycle event.
StepDurability
Was optimize_activity: false=SYNC, true=ASYNC. Timer is always optimized by the server.
StopType
SubFlowCompletionDeliveryStatus
SubFlowReusePolicy
UpdateErrorType
WaitForMethodFailurePolicy
WaitingConditionType