#[repr(i32)]pub enum FlowErrorType {
Unspecified = 0,
StepDecisionFailingFlow = 1,
ClientApiFailingFlow = 2,
WorkerApiFail = 3,
InvalidUserFlowCode = 4,
Internal = 6,
}Variants
Unspecified = 0
StepDecisionFailingFlow = 1
ClientApiFailingFlow = 2
WorkerApiFail = 3
includes waitFor/execute/rpc methods
InvalidUserFlowCode = 4
Internal = 6
either bug in sdk or server
Implementations
Sourceimpl FlowErrorType
impl FlowErrorType
Sourceimpl FlowErrorType
impl FlowErrorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.