#[repr(i32)]pub enum FlowStatus {
Unspecified = 0,
Running = 1,
Completed = 2,
Failed = 3,
Timeout = 4,
Terminated = 5,
Canceled = 6,
ContinuedAsNew = 7,
}Variants
Unspecified = 0
Running = 1
Completed = 2
Failed = 3
Timeout = 4
Terminated = 5
Canceled = 6
ContinuedAsNew = 7
Implementations
Sourceimpl FlowStatus
impl FlowStatus
Sourceimpl FlowStatus
impl FlowStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.