#[repr(i32)]pub enum PendingStepMethodPhase {
Unspecified = 0,
Scheduled = 1,
Started = 2,
}Expand description
PendingStepMethodPhase reports the latest persisted backend lifecycle event.
Variants
Implementations
Sourceimpl PendingStepMethodPhase
impl PendingStepMethodPhase
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of PendingStepMethodPhase.
Sourcepub fn from_i32(value: i32) -> Option<PendingStepMethodPhase>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<PendingStepMethodPhase>
Use the TryFrom<i32> implementation instead
Converts an i32 to a PendingStepMethodPhase, or None if value is not a valid variant.
Sourceimpl PendingStepMethodPhase
impl PendingStepMethodPhase
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.