FlowServiceClient

Struct FlowServiceClient 

pub struct FlowServiceClient<T> { /* private fields */ }
Hosted by Dex server; SDKs call these RPCs.

Implementations

Source

impl FlowServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> FlowServiceClient<T>
where T: GrpcService<Body>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> FlowServiceClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>, <T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn start_flow( &mut self, request: impl IntoRequest<StartFlowRequest>, ) -> Result<Response<StartFlowResponse>, Status>

pub async fn publish_to_channel( &mut self, request: impl IntoRequest<PublishToChannelRequest>, ) -> Result<Response<()>, Status>

pub async fn get_channel_messages( &mut self, request: impl IntoRequest<GetChannelMessagesRequest>, ) -> Result<Response<GetChannelMessagesResponse>, Status>

pub async fn delete_channel_message( &mut self, request: impl IntoRequest<DeleteChannelMessageRequest>, ) -> Result<Response<()>, Status>

pub async fn write_stream( &mut self, request: impl IntoRequest<WriteStreamRequest>, ) -> Result<Response<()>, Status>

pub async fn read_stream( &mut self, request: impl IntoRequest<ReadStreamRequest>, ) -> Result<Response<ReadStreamResponse>, Status>

pub async fn stop_flow( &mut self, request: impl IntoRequest<StopFlowRequest>, ) -> Result<Response<()>, Status>

pub async fn get_attributes( &mut self, request: impl IntoRequest<GetAttributesRequest>, ) -> Result<Response<GetAttributesResponse>, Status>

pub async fn set_attributes( &mut self, request: impl IntoRequest<SetAttributesRequest>, ) -> Result<Response<()>, Status>

pub async fn load_blobs( &mut self, request: impl IntoRequest<LoadBlobsRequest>, ) -> Result<Response<LoadBlobsResponse>, Status>

pub async fn wait_for_flow( &mut self, request: impl IntoRequest<WaitForFlowRequest>, ) -> Result<Response<FlowResult>, Status>

pub async fn search_flows( &mut self, request: impl IntoRequest<SearchFlowsRequest>, ) -> Result<Response<SearchFlowsResponse>, Status>

pub async fn sync_attribute_indexes( &mut self, request: impl IntoRequest<SyncAttributeIndexRequest>, ) -> Result<Response<SyncAttributeIndexResponse>, Status>

pub async fn get_flow_summary( &mut self, request: impl IntoRequest<GetFlowSummaryRequest>, ) -> Result<Response<GetFlowSummaryResponse>, Status>

pub async fn get_history_events( &mut self, request: impl IntoRequest<GetHistoryEventsRequest>, ) -> Result<Response<GetHistoryEventsResponse>, Status>

pub async fn wait_for_history_event( &mut self, request: impl IntoRequest<WaitForHistoryEventRequest>, ) -> Result<Response<WaitForHistoryEventResponse>, Status>

pub async fn get_flow_state( &mut self, request: impl IntoRequest<GetFlowStateRequest>, ) -> Result<Response<GetFlowStateResponse>, Status>

pub async fn reset_flow( &mut self, request: impl IntoRequest<ResetFlowRequest>, ) -> Result<Response<ResetFlowResponse>, Status>

pub async fn invoke_rpc( &mut self, request: impl IntoRequest<InvokeRpcRequest>, ) -> Result<Response<InvokeRpcResponse>, Status>

pub async fn skip_timer( &mut self, request: impl IntoRequest<SkipTimerRequest>, ) -> Result<Response<()>, Status>

pub async fn update_flow_config( &mut self, request: impl IntoRequest<UpdateFlowConfigRequest>, ) -> Result<Response<()>, Status>

pub async fn wait_for_step_completion( &mut self, request: impl IntoRequest<WaitForStepCompletionRequest>, ) -> Result<Response<WaitForStepCompletionResponse>, Status>

pub async fn wait_for_attribute( &mut self, request: impl IntoRequest<WaitForAttributeRequest>, ) -> Result<Response<()>, Status>

pub async fn trigger_continue_as_new( &mut self, request: impl IntoRequest<TriggerContinueAsNewRequest>, ) -> Result<Response<()>, Status>

pub async fn health_check( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<HealthInfo>, Status>