pub struct ActiveStepExecutionState {
pub step_execution_id: String,
pub from_step_execution_id: String,
pub step_type: String,
pub phase: i32,
pub movement: Option<StepMovement>,
pub waiting_condition: Option<WaitingConditionState>,
pub completed_conditions: Option<StepExecutionCompletedConditions>,
pub step_execution_locals: Vec<Kv>,
pub timers: Vec<TimerInfo>,
pub last_failure_info: Option<StepMethodFailure>,
}Fields
step_execution_id: Stringfrom_step_execution_id: Stringstep_type: Stringphase: i32movement: Option<StepMovement>waiting_condition: Option<WaitingConditionState>completed_conditions: Option<StepExecutionCompletedConditions>step_execution_locals: Vec<Kv>timers: Vec<TimerInfo>last_failure_info: Option<StepMethodFailure>Implementations
Sourceimpl ActiveStepExecutionState
impl ActiveStepExecutionState
Sourcepub fn phase(&self) -> ActiveStepPhase
pub fn phase(&self) -> ActiveStepPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: ActiveStepPhase)
pub fn set_phase(&mut self, value: ActiveStepPhase)
Sets phase to the provided enum value.