pub struct AttributeMatch {
pub key: String,
pub operator: i32,
pub operand: Option<Value>,
}Fields
key: Stringoperator: i32operand: Option<Value>Implementations
Sourceimpl AttributeMatch
impl AttributeMatch
Sourcepub fn operator(&self) -> AttributeMatchOperator
pub fn operator(&self) -> AttributeMatchOperator
Returns the enum value of operator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operator(&mut self, value: AttributeMatchOperator)
pub fn set_operator(&mut self, value: AttributeMatchOperator)
Sets operator to the provided enum value.