pub struct AttributeWrite {
pub key: String,
pub value: Option<Value>,
pub index_config: Option<IndexConfig>,
pub sync_config: Option<AttributeSyncConfig>,
}Fields
key: Stringvalue: Option<Value>index_config: Option<IndexConfig>Omit when indexing is inferred or attribute is not indexed.
sync_config: Option<AttributeSyncConfig>Omit or disable to keep this write out of the configured Attribute Store.