pub struct Context {
pub flow_id: String,
pub run_id: String,
pub flow_started_timestamp: i64,
pub step_execution_id: String,
pub first_attempt_timestamp: i64,
pub attempt: i32,
pub from_step_execution_id: String,
pub recovery_error: Option<RecoveryErrorInfo>,
}Fields
flow_id: Stringrun_id: Stringflow_started_timestamp: i64step_execution_id: Stringfirst_attempt_timestamp: i64attempt: i32from_step_execution_id: StringStep execution that scheduled this execution, or a reserved source.
recovery_error: Option<RecoveryErrorInfo>Previous Step method failure supplied only to its configured recovery method.