pub struct ContinueAsNewDump {
pub steps_to_start_from_beginning: Vec<StepMovement>,
pub step_executions_to_resume: Vec<StepExecutionResumeInfo>,
pub channel_received: HashMap<String, ChannelValues>,
pub counter_info: Option<StepExecutionCounterInfo>,
pub step_outputs: Vec<StepCompletionOutput>,
pub stale_skip_timers: Vec<StaleSkipTimer>,
pub attributes: Vec<Kv>,
pub pending_attribute_sync_items: Vec<AttributeSyncItem>,
}Fields
steps_to_start_from_beginning: Vec<StepMovement>step_executions_to_resume: Vec<StepExecutionResumeInfo>channel_received: HashMap<String, ChannelValues>counter_info: Option<StepExecutionCounterInfo>step_outputs: Vec<StepCompletionOutput>stale_skip_timers: Vec<StaleSkipTimer>attributes: Vec<Kv>Stored values only; index metadata remains in backend search attributes.
pending_attribute_sync_items: Vec<AttributeSyncItem>Trait Implementations
Sourceimpl Clone for ContinueAsNewDump
impl Clone for ContinueAsNewDump
Sourcefn clone(&self) -> ContinueAsNewDump
fn clone(&self) -> ContinueAsNewDump
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContinueAsNewDump
impl Debug for ContinueAsNewDump
Sourceimpl Default for ContinueAsNewDump
impl Default for ContinueAsNewDump
Sourceimpl Message for ContinueAsNewDump
impl Message for ContinueAsNewDump
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ContinueAsNewDump
impl PartialEq for ContinueAsNewDump
impl StructuralPartialEq for ContinueAsNewDump