pub struct ExecuteRpcSignalRequest {
pub rpc_input: Option<Value>,
pub rpc_output: Option<Value>,
pub upsert_attributes: Vec<AttributeWrite>,
pub step_decision: Option<StepDecision>,
pub record_events: Vec<Kv>,
pub publish_to_channel: Vec<ChannelMessage>,
}Fields
rpc_input: Option<Value>rpc_output: Option<Value>upsert_attributes: Vec<AttributeWrite>step_decision: Option<StepDecision>record_events: Vec<Kv>publish_to_channel: Vec<ChannelMessage>Trait Implementations
Sourceimpl Clone for ExecuteRpcSignalRequest
impl Clone for ExecuteRpcSignalRequest
Sourcefn clone(&self) -> ExecuteRpcSignalRequest
fn clone(&self) -> ExecuteRpcSignalRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecuteRpcSignalRequest
impl Debug for ExecuteRpcSignalRequest
Sourceimpl Default for ExecuteRpcSignalRequest
impl Default for ExecuteRpcSignalRequest
Sourceimpl Message for ExecuteRpcSignalRequest
impl Message for ExecuteRpcSignalRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ExecuteRpcSignalRequest
impl PartialEq for ExecuteRpcSignalRequest
impl StructuralPartialEq for ExecuteRpcSignalRequest