pub struct FlowClosedHistoryEvent {
pub flow_status: i32,
pub results: Vec<StepCompletionOutput>,
pub error_type: i32,
pub error_message: String,
pub continued_to_run_id: String,
}Fields
flow_status: i32results: Vec<StepCompletionOutput>error_type: i32error_message: Stringcontinued_to_run_id: StringImplementations
Sourceimpl FlowClosedHistoryEvent
impl FlowClosedHistoryEvent
Sourcepub fn flow_status(&self) -> FlowStatus
pub fn flow_status(&self) -> FlowStatus
Returns the enum value of flow_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_flow_status(&mut self, value: FlowStatus)
pub fn set_flow_status(&mut self, value: FlowStatus)
Sets flow_status to the provided enum value.
Sourcepub fn error_type(&self) -> FlowErrorType
pub fn error_type(&self) -> FlowErrorType
Returns the enum value of error_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error_type(&mut self, value: FlowErrorType)
pub fn set_error_type(&mut self, value: FlowErrorType)
Sets error_type to the provided enum value.