pub struct FlowConfig {
pub active_step_search_mode: Option<i32>,
pub continue_as_new_threshold: Option<i32>,
pub continue_as_new_page_size_in_bytes: Option<i32>,
pub step_durability: Option<i32>,
pub worker_target: Option<WorkerTarget>,
pub attribute_store_names: Option<AttributeStoreNames>,
}Fields
active_step_search_mode: Option<i32>continue_as_new_threshold: Option<i32>continue_as_new_page_size_in_bytes: Option<i32>step_durability: Option<i32>worker_target: Option<WorkerTarget>attribute_store_names: Option<AttributeStoreNames>Present empty disables future synchronization; non-empty selects Server-configured stores.
Implementations
Sourceimpl FlowConfig
impl FlowConfig
Sourcepub fn active_step_search_mode(&self) -> ActiveStepSearchMode
pub fn active_step_search_mode(&self) -> ActiveStepSearchMode
Returns the enum value of active_step_search_mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_active_step_search_mode(&mut self, value: ActiveStepSearchMode)
pub fn set_active_step_search_mode(&mut self, value: ActiveStepSearchMode)
Sets active_step_search_mode to the provided enum value.
Sourcepub fn continue_as_new_threshold(&self) -> i32
pub fn continue_as_new_threshold(&self) -> i32
Returns the value of continue_as_new_threshold, or the default value if continue_as_new_threshold is unset.
Sourcepub fn continue_as_new_page_size_in_bytes(&self) -> i32
pub fn continue_as_new_page_size_in_bytes(&self) -> i32
Returns the value of continue_as_new_page_size_in_bytes, or the default value if continue_as_new_page_size_in_bytes is unset.
Sourcepub fn step_durability(&self) -> StepDurability
pub fn step_durability(&self) -> StepDurability
Returns the enum value of step_durability, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_step_durability(&mut self, value: StepDurability)
pub fn set_step_durability(&mut self, value: StepDurability)
Sets step_durability to the provided enum value.