pub struct FlowContinuedStart {
pub previous_run_id: String,
pub steps_to_start: Vec<StepMovement>,
pub steps_to_resume: Vec<StepExecutionResumeInfo>,
pub pending_channel_messages: HashMap<String, ChannelValues>,
pub attributes: Vec<Kv>,
pub completed_steps: Vec<StepCompletionOutput>,
}Fields
previous_run_id: Stringsteps_to_start: Vec<StepMovement>steps_to_resume: Vec<StepExecutionResumeInfo>pending_channel_messages: HashMap<String, ChannelValues>attributes: Vec<Kv>completed_steps: Vec<StepCompletionOutput>Trait Implementations
Sourceimpl Clone for FlowContinuedStart
impl Clone for FlowContinuedStart
Sourcefn clone(&self) -> FlowContinuedStart
fn clone(&self) -> FlowContinuedStart
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowContinuedStart
impl Debug for FlowContinuedStart
Sourceimpl Default for FlowContinuedStart
impl Default for FlowContinuedStart
Sourceimpl Message for FlowContinuedStart
impl Message for FlowContinuedStart
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FlowContinuedStart
impl PartialEq for FlowContinuedStart
impl StructuralPartialEq for FlowContinuedStart