pub struct FlowTimeoutHandlerOptions {
pub method_timeout_seconds: i32,
pub heartbeat_timeout_seconds: i32,
pub retry_policy: Option<RetryPolicy>,
pub failure_policy: i32,
pub failure_proceed_step_type: String,
pub failure_proceed_step_options: Option<StepOptions>,
pub durability_override: i32,
pub lock_attribute_keys: Vec<String>,
pub load_attribute_map_instances: Vec<String>,
pub load_channel_names: Vec<String>,
pub load_channel_map_instances: Vec<String>,
}Fields
method_timeout_seconds: i32heartbeat_timeout_seconds: i32retry_policy: Option<RetryPolicy>failure_policy: i32failure_proceed_step_type: Stringfailure_proceed_step_options: Option<StepOptions>durability_override: i32lock_attribute_keys: Vec<String>load_attribute_map_instances: Vec<String>load_channel_names: Vec<String>load_channel_map_instances: Vec<String>Implementations
Sourceimpl FlowTimeoutHandlerOptions
impl FlowTimeoutHandlerOptions
Sourcepub fn failure_policy(&self) -> ExecuteMethodFailurePolicy
pub fn failure_policy(&self) -> ExecuteMethodFailurePolicy
Returns the enum value of failure_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_failure_policy(&mut self, value: ExecuteMethodFailurePolicy)
pub fn set_failure_policy(&mut self, value: ExecuteMethodFailurePolicy)
Sets failure_policy to the provided enum value.
Sourcepub fn durability_override(&self) -> StepDurability
pub fn durability_override(&self) -> StepDurability
Returns the enum value of durability_override, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability_override(&mut self, value: StepDurability)
pub fn set_durability_override(&mut self, value: StepDurability)
Sets durability_override to the provided enum value.