pub struct InvokeWaitForMethodResponse {
pub local_activity_metadata: Option<LocalActivityMetadata>,
pub upsert_attributes: Vec<AttributeWrite>,
pub waiting_condition: Option<WaitingCondition>,
pub upsert_step_exe_locals: Vec<Kv>,
pub record_events: Vec<Kv>,
pub publish_to_channel: Vec<ChannelMessage>,
pub delete_from_channel: Vec<ChannelMessageDeletion>,
}Fields
local_activity_metadata: Option<LocalActivityMetadata>Server-populated lineage input for local activity history.
upsert_attributes: Vec<AttributeWrite>waiting_condition: Option<WaitingCondition>upsert_step_exe_locals: Vec<Kv>record_events: Vec<Kv>publish_to_channel: Vec<ChannelMessage>delete_from_channel: Vec<ChannelMessageDeletion>Trait Implementations
Sourceimpl Clone for InvokeWaitForMethodResponse
impl Clone for InvokeWaitForMethodResponse
Sourcefn clone(&self) -> InvokeWaitForMethodResponse
fn clone(&self) -> InvokeWaitForMethodResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvokeWaitForMethodResponse
impl Debug for InvokeWaitForMethodResponse
Sourceimpl Message for InvokeWaitForMethodResponse
impl Message for InvokeWaitForMethodResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for InvokeWaitForMethodResponse