pub struct PrepareRpcQueryResponse {
pub attributes: Vec<Kv>,
pub run_id: String,
pub flow_started_timestamp: i64,
pub flow_type: String,
pub worker_target: Option<WorkerTarget>,
pub channel_infos: HashMap<String, ChannelInfo>,
pub loaded_channel_messages: HashMap<String, ChannelValues>,
pub loaded_attribute_map_instances: Vec<String>,
pub loaded_channel_names: Vec<String>,
pub loaded_channel_map_instances: Vec<String>,
}Fields
attributes: Vec<Kv>run_id: Stringflow_started_timestamp: i64flow_type: Stringworker_target: Option<WorkerTarget>channel_infos: HashMap<String, ChannelInfo>loaded_channel_messages: HashMap<String, ChannelValues>loaded_attribute_map_instances: Vec<String>loaded_channel_names: Vec<String>loaded_channel_map_instances: Vec<String>Trait Implementations
Sourceimpl Clone for PrepareRpcQueryResponse
impl Clone for PrepareRpcQueryResponse
Sourcefn clone(&self) -> PrepareRpcQueryResponse
fn clone(&self) -> PrepareRpcQueryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareRpcQueryResponse
impl Debug for PrepareRpcQueryResponse
Sourceimpl Default for PrepareRpcQueryResponse
impl Default for PrepareRpcQueryResponse
Sourceimpl Message for PrepareRpcQueryResponse
impl Message for PrepareRpcQueryResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PrepareRpcQueryResponse
impl PartialEq for PrepareRpcQueryResponse
impl StructuralPartialEq for PrepareRpcQueryResponse