pub struct ReportSubFlowCompletionActivityOutput {
pub status: i32,
}Fields
status: i32Implementations
Sourceimpl ReportSubFlowCompletionActivityOutput
impl ReportSubFlowCompletionActivityOutput
Sourcepub fn status(&self) -> SubFlowCompletionDeliveryStatus
pub fn status(&self) -> SubFlowCompletionDeliveryStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SubFlowCompletionDeliveryStatus)
pub fn set_status(&mut self, value: SubFlowCompletionDeliveryStatus)
Sets status to the provided enum value.