pub struct StepExecuteCompletedOutput {
pub step_decision: Option<StepDecision>,
pub upsert_attributes: Vec<AttributeWrite>,
pub publish_to_channel: Vec<ChannelMessage>,
pub record_events: Vec<Kv>,
pub upsert_step_execution_locals: Vec<Kv>,
pub delete_from_channel: Vec<ChannelMessageDeletion>,
}Fields
step_decision: Option<StepDecision>upsert_attributes: Vec<AttributeWrite>publish_to_channel: Vec<ChannelMessage>record_events: Vec<Kv>upsert_step_execution_locals: Vec<Kv>delete_from_channel: Vec<ChannelMessageDeletion>Trait Implementations
Sourceimpl Clone for StepExecuteCompletedOutput
impl Clone for StepExecuteCompletedOutput
Sourcefn clone(&self) -> StepExecuteCompletedOutput
fn clone(&self) -> StepExecuteCompletedOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StepExecuteCompletedOutput
impl Debug for StepExecuteCompletedOutput
Sourceimpl Default for StepExecuteCompletedOutput
impl Default for StepExecuteCompletedOutput
Sourceimpl Message for StepExecuteCompletedOutput
impl Message for StepExecuteCompletedOutput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for StepExecuteCompletedOutput