pub struct StepExecutionCompletedConditions {
pub completed_timer_conditions: HashMap<i32, i32>,
pub completed_sub_flow_results: HashMap<i32, FlowResult>,
}Fields
completed_timer_conditions: HashMap<i32, i32>completed_sub_flow_results: HashMap<i32, FlowResult>Implementations
Sourceimpl StepExecutionCompletedConditions
impl StepExecutionCompletedConditions
Sourcepub fn get_completed_timer_conditions(
&self,
key: i32,
) -> Option<InternalTimerStatus>
pub fn get_completed_timer_conditions( &self, key: i32, ) -> Option<InternalTimerStatus>
Returns the enum value for the corresponding key in completed_timer_conditions, or None if the entry does not exist or it is not a valid enum value.
Sourcepub fn insert_completed_timer_conditions(
&mut self,
key: i32,
value: InternalTimerStatus,
) -> Option<InternalTimerStatus>
pub fn insert_completed_timer_conditions( &mut self, key: i32, value: InternalTimerStatus, ) -> Option<InternalTimerStatus>
Inserts a key value pair into completed_timer_conditions.