pub struct StepMethodEventContext {
pub step_execution_id: String,
pub from_step_execution_id: String,
pub step_type: String,
pub durability: i32,
pub final_attempt: i32,
pub started_time: Option<Timestamp>,
pub duration: Option<Duration>,
pub method_options: Option<StepMethodOptions>,
pub last_failure_info: Option<StepMethodFailure>,
}Fields
step_execution_id: Stringfrom_step_execution_id: Stringstep_type: Stringdurability: i32final_attempt: i32started_time: Option<Timestamp>duration: Option<Duration>method_options: Option<StepMethodOptions>last_failure_info: Option<StepMethodFailure>Implementations
Sourceimpl StepMethodEventContext
impl StepMethodEventContext
Sourcepub fn durability(&self) -> StepDurability
pub fn durability(&self) -> StepDurability
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: StepDurability)
pub fn set_durability(&mut self, value: StepDurability)
Sets durability to the provided enum value.