pub struct StepMethodPendingEvent {
pub input: Option<StepMethodEventInput>,
pub context: Option<StepMethodEventContext>,
pub phase: i32,
}Expand description
StepMethodPendingEvent describes a regular Step activity unresolved at flow closure.
Fields
input: Option<StepMethodEventInput>context: Option<StepMethodEventContext>phase: i32Implementations
Sourceimpl StepMethodPendingEvent
impl StepMethodPendingEvent
Sourcepub fn phase(&self) -> PendingStepMethodPhase
pub fn phase(&self) -> PendingStepMethodPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: PendingStepMethodPhase)
pub fn set_phase(&mut self, value: PendingStepMethodPhase)
Sets phase to the provided enum value.