pub struct StepOptions {Show 20 fields
pub wait_for_timeout_seconds: i32,
pub execute_timeout_seconds: i32,
pub wait_for_retry_policy: Option<RetryPolicy>,
pub execute_retry_policy: Option<RetryPolicy>,
pub wait_for_failure_policy: i32,
pub execute_failure_policy: i32,
pub execute_failure_proceed_step_type: String,
pub execute_failure_proceed_step_options: Option<Box<StepOptions>>,
pub skip_wait_for: bool,
pub wait_for_durability_override: i32,
pub execute_durability_override: i32,
pub wait_for_lock_attribute_keys: Vec<String>,
pub execute_lock_attribute_keys: Vec<String>,
pub heartbeat_timeout_seconds: i32,
pub wait_for_load_attribute_map_instances: Vec<String>,
pub wait_for_load_channel_names: Vec<String>,
pub wait_for_load_channel_map_instances: Vec<String>,
pub execute_load_attribute_map_instances: Vec<String>,
pub execute_load_channel_names: Vec<String>,
pub execute_load_channel_map_instances: Vec<String>,
}Fields
wait_for_timeout_seconds: i32execute_timeout_seconds: i32wait_for_retry_policy: Option<RetryPolicy>execute_retry_policy: Option<RetryPolicy>wait_for_failure_policy: i32execute_failure_policy: i32execute_failure_proceed_step_type: Stringexecute_failure_proceed_step_options: Option<Box<StepOptions>>skip_wait_for: boolwait_for_durability_override: i32execute_durability_override: i32wait_for_lock_attribute_keys: Vec<String>execute_lock_attribute_keys: Vec<String>heartbeat_timeout_seconds: i32wait_for_load_attribute_map_instances: Vec<String>wait_for_load_channel_names: Vec<String>wait_for_load_channel_map_instances: Vec<String>execute_load_attribute_map_instances: Vec<String>execute_load_channel_names: Vec<String>execute_load_channel_map_instances: Vec<String>Implementations
Sourceimpl StepOptions
impl StepOptions
Sourcepub fn wait_for_failure_policy(&self) -> WaitForMethodFailurePolicy
pub fn wait_for_failure_policy(&self) -> WaitForMethodFailurePolicy
Returns the enum value of wait_for_failure_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_wait_for_failure_policy(&mut self, value: WaitForMethodFailurePolicy)
pub fn set_wait_for_failure_policy(&mut self, value: WaitForMethodFailurePolicy)
Sets wait_for_failure_policy to the provided enum value.
Sourcepub fn execute_failure_policy(&self) -> ExecuteMethodFailurePolicy
pub fn execute_failure_policy(&self) -> ExecuteMethodFailurePolicy
Returns the enum value of execute_failure_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_execute_failure_policy(&mut self, value: ExecuteMethodFailurePolicy)
pub fn set_execute_failure_policy(&mut self, value: ExecuteMethodFailurePolicy)
Sets execute_failure_policy to the provided enum value.
Sourcepub fn wait_for_durability_override(&self) -> StepDurability
pub fn wait_for_durability_override(&self) -> StepDurability
Returns the enum value of wait_for_durability_override, or the default if the field is set to an invalid enum value.
Sourcepub fn set_wait_for_durability_override(&mut self, value: StepDurability)
pub fn set_wait_for_durability_override(&mut self, value: StepDurability)
Sets wait_for_durability_override to the provided enum value.
Sourcepub fn execute_durability_override(&self) -> StepDurability
pub fn execute_durability_override(&self) -> StepDurability
Returns the enum value of execute_durability_override, or the default if the field is set to an invalid enum value.
Sourcepub fn set_execute_durability_override(&mut self, value: StepDurability)
pub fn set_execute_durability_override(&mut self, value: StepDurability)
Sets execute_durability_override to the provided enum value.