pub struct SubFlowOptions {
pub reuse_policy: i32,
pub flow_timeout_seconds: i32,
pub flow_start_delay_seconds: i32,
pub retry_policy: Option<FlowRetryPolicy>,
pub attributes: Vec<AttributeWrite>,
pub flow_config_override: Option<FlowConfig>,
pub flow_timeout_policy: i32,
}Fields
reuse_policy: i32flow_timeout_seconds: i32flow_start_delay_seconds: i32retry_policy: Option<FlowRetryPolicy>attributes: Vec<AttributeWrite>flow_config_override: Option<FlowConfig>flow_timeout_policy: i32Implementations
Sourceimpl SubFlowOptions
impl SubFlowOptions
Sourcepub fn reuse_policy(&self) -> SubFlowReusePolicy
pub fn reuse_policy(&self) -> SubFlowReusePolicy
Returns the enum value of reuse_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reuse_policy(&mut self, value: SubFlowReusePolicy)
pub fn set_reuse_policy(&mut self, value: SubFlowReusePolicy)
Sets reuse_policy to the provided enum value.
Sourcepub fn flow_timeout_policy(&self) -> FlowTimeoutPolicy
pub fn flow_timeout_policy(&self) -> FlowTimeoutPolicy
Returns the enum value of flow_timeout_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_flow_timeout_policy(&mut self, value: FlowTimeoutPolicy)
pub fn set_flow_timeout_policy(&mut self, value: FlowTimeoutPolicy)
Sets flow_timeout_policy to the provided enum value.