pub struct SyncAttributeIndexRequest {
pub attribute_indexes: HashMap<String, i32>,
}Fields
attribute_indexes: HashMap<String, i32>Implementations
Sourceimpl SyncAttributeIndexRequest
impl SyncAttributeIndexRequest
Sourcepub fn get_attribute_indexes(&self, key: &str) -> Option<IndexType>
pub fn get_attribute_indexes(&self, key: &str) -> Option<IndexType>
Returns the enum value for the corresponding key in attribute_indexes, or None if the entry does not exist or it is not a valid enum value.