pub struct TimerInfo {
pub condition_id: String,
pub firing_unix_timestamp_seconds: i64,
pub status: i32,
}Fields
condition_id: StringEmpty when the timer has no condition id.
firing_unix_timestamp_seconds: i64status: i32Implementations
Sourceimpl TimerInfo
impl TimerInfo
Sourcepub fn status(&self) -> InternalTimerStatus
pub fn status(&self) -> InternalTimerStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: InternalTimerStatus)
pub fn set_status(&mut self, value: InternalTimerStatus)
Sets status to the provided enum value.